'****************************************************************
'*  Name    : DeviceList.inc                                    *
'*  Author  : [Alberto Freixanet]                               *
'*  Notice  : Copyright (c) 2017 [AFreixanet]                   *
'*          : All Rights Reserved                               *
'*  Date    : 28/10/2017                                        *
'*  Version : 1.0                                               *
'*  Notes   : Device ID number of the Microchip PICs            *
'****************************************************************
'
' Version 1.1 2018/01/09
' Added the example code to use this library.

'===============================================================================
(*
 HOW TO USE THIS LIBRARY.
'-------------------------------------------------------------------------------
    ' Incliude the Library 
    Include "D:\MyIncFiles\Devicelist.inc"
    '---------------------------------------------------------------------------
    Dim DataWord As Word
    Dim PICPartNumber As Word
    Dim PICRevision As Byte    
'-------------------------------------------------------------------------------
    ' Read the DEVID1 (Device ID) from the PPI/asm file.
    EECON1 = %10000000               ' Access Flash memory
    Set_Bank TBLPTRL
    Asm
    Movlw Low (DEVID1)
    Movwf TBLPTRL
    Movlw High (DEVID1)
    Movwf TBLPTRH
    Movlw upper (DEVID1)
    Movwf TBLPTRU
    EndAsm
    Tblrd*+                         ' perform table read with post-increment
    DataWord.LowByte = TABLAT
    Tblrd*+                         ' perform table read with post-increment
    DataWord.HighByte = TABLAT        
    TBLPTRU = 0                     ' Cleared for security
    EECON1 = 0                      ' Disable Access the Flash memory
    '---------------------------------------------------------------------------
    ' Calculate the PIC Part Number & revision
    PICPartNumber = DataWord >> 5
    PICRevision = DataWord.LowByte & 31
'-------------------------------------------------------------------------------
    ' Print the Device Name to the Terminal.
    $ifndef __DEVICE_ID
        $error "The Devicelist.inc is missing!!"
    $endif
    Select PICPartNumber
        Case __DEVICE_ID
            HRSOut "Device = ", __DEVICE_NAME, CR,LF
        Case Else
            HRSOut CR,LF    
            HRSOut "The PIC Device read from the Board is not correct!",CR,LF   
            HRSOut CR,LF        
    EndSelect    
    '---------------------------------------------------------------------------
    HRSOut "FOSC: ", Dec _xtal," Mhz"
    $ifdef _InternalOSC_
    HRSOut " Internal Oscillator ",CR,LF    
    $else
    HRSOut " Xtal Oscillator ",CR,LF    
    $endif
    HRSOut "PIC Part Number: ", Dec PICPartNumber, " / $", Hex4 PICPartNumber 
    HRSOut ", Revision: ", Dec PICRevision, " / $", Hex2 PICRevision,CR,LF

    $if PLL_ConfigFuses = On
        HRSOut "The PLL is used!",CR,LF
    $else
        $if PLL_ConfigFuses = OFF    
            HRSOut "FOSC without PLL!",CR,LF
        $endif
    $endif
'-------------------------------------------------------------------------------    
*)
'===============================================================================
'===============================================================================
' If your new Device ID is not in the list, please add it reading the PICxxxx.dev files in the MPLAB folder.

    $if _device = _18F242
    $define __DEVICE_ID 36
    $define __DEVICE_NAME "PIC18F242"
    $endif

    $if _device = _18F248
    $define __DEVICE_ID 64
    $define __DEVICE_NAME "PIC18F248"
    $endif

    $if _device = _18F252
    $define __DEVICE_ID 32
    $define __DEVICE_NAME "PIC18F252"
    $endif

    $if _device = _18F258
    $define __DEVICE_ID 66
    $define __DEVICE_NAME "PIC18F258" 
    $endif

    $if _device = _18F442
    $define __DEVICE_ID 37
    $define __DEVICE_NAME "PIC18F442"
    $endif

    $if _device = _18F448
    $define __DEVICE_ID 65
    $define __DEVICE_NAME "PIC18F448"
    $endif
    
    $if _device = _18F452
    $define __DEVICE_ID 33
    $define __DEVICE_NAME "PIC18F452"
    $endif
    
    $if _device = _18F458
    $define __DEVICE_ID 67
    $define __DEVICE_NAME "PIC18F458"
    $endif
'-------------------------------------------------------------------------------
    $if _device = _18F1220
    $define __DEVICE_ID 62
    $define __DEVICE_NAME "PIC18F1220"
    $endif

    $if _device = _18F1230
    $define __DEVICE_ID 240
    $define __DEVICE_NAME "PIC18F1230"
    $endif

    $if _device = _18F1231
    $define __DEVICE_ID 244
    $define __DEVICE_NAME "PIC18F1231"
    $endif

    $if _device = _18F1320
    $define __DEVICE_ID 62
    $define __DEVICE_NAME "PIC18F1320"
    $endif

    $if _device = _18F1330
    $define __DEVICE_ID 241
    $define __DEVICE_NAME "PIC18F1330"
    $endif    

    $if _device = _18F1331
    $define __DEVICE_ID 245
    $define __DEVICE_NAME "PIC18F1331"
    $endif    
'-------------------------------------------------------------------------------
    $if _device = _18F2220
    $define __DEVICE_ID 44
    $define __DEVICE_NAME "PIC18F2220"
    $endif    

    $if _device = _18F2221
    $define __DEVICE_ID 267
    $define __DEVICE_NAME "PIC18F2221"
    $endif    
'-------------------------------------------------------------------------------
    $if _device = _18F2320
    $define __DEVICE_ID 40
    $define __DEVICE_NAME "PIC18F2320"
    $endif    

    $if _device = _18F2321
    $define __DEVICE_ID 265
    $define __DEVICE_NAME "PIC18F2321"
    $endif

    $if _device = _18F2331
    $define __DEVICE_ID 71
    $define __DEVICE_NAME "PIC18F2331"
    $endif    
'-------------------------------------------------------------------------------
    $if _device = _18F2410
    $define __DEVICE_ID 139
    $define __DEVICE_NAME "PIC18F2410"
    $endif

    $if _device = _18F2420
    $define __DEVICE_ID 138
    $define __DEVICE_NAME "PIC18F2420"
    $endif    

    $if _device = _18F2423
    $define __DEVICE_ID 138    
    $define __DEVICE_NAME "PIC18F2423"
    $endif

    $if _device = _18F2431
    $define __DEVICE_ID 70
    $define __DEVICE_NAME "PIC18F2431"
    $endif

    $if _device = _18F2439
    $define __DEVICE_ID 36
    $define __DEVICE_NAME "PIC18F2682"
    $endif

    $if _device = _18F2450
    $define __DEVICE_ID 289
    $define __DEVICE_NAME "PIC18F2450"
    $endif
'-------------------------------------------------------------------------------
    $if _device = _18F2510
    $define __DEVICE_ID 137
    $define __DEVICE_NAME "PIC18F2439"
    $endif

    $if _device = _18F2515
    $define __DEVICE_ID 103
    $define __DEVICE_NAME "PIC18F2515"
    $endif

    $if _device = _18F2520
    $define __DEVICE_ID 136
    $define __DEVICE_NAME "PIC18F2520"
    $endif

    $if _device = _18F2523
    $define __DEVICE_ID 136
    $define __DEVICE_NAME "PIC18F2523"
    $endif    

    $if _device = _18F2525
    $define __DEVICE_ID 102
    $define __DEVICE_NAME "PIC18F2525"
    $endif

    $if _device = _18F2550
    $define __DEVICE_ID 146
    $define __DEVICE_NAME "PIC18F2550"
    $endif

    $if _device = _18F2585
    $define __DEVICE_ID 119
    $define __DEVICE_NAME "PIC18F2585"
    $endif
'-------------------------------------------------------------------------------
    $if _device = _18F2620
    $define __DEVICE_ID 100    
    $define __DEVICE_NAME "PIC18F2620"
    $endif

    $if _device = _18F2680
    $define __DEVICE_ID 118  
    $define __DEVICE_NAME "PIC18F2680"
    $endif

    $if _device = _18F2682
    $define __DEVICE_ID 312  
    $define __DEVICE_NAME "PIC18F2682"
    $endif

    $if _device = _18F2685
    $define __DEVICE_ID 313
    $define __DEVICE_NAME "PIC18F2685"
    $endif    
'-------------------------------------------------------------------------------
    $if _device = _18F4420
    $define __DEVICE_ID 134
    $define __DEVICE_NAME "PIC18F4420"
    $endif

    $if _device = _18F4450
    $define __DEVICE_ID 288
    $define __DEVICE_NAME "PIC18F4450"
    $endif

'-------------------------------------------------------------------------------
    $if _device = _18F4510
    $define __DEVICE_ID 133
    $define __DEVICE_NAME "PIC18F4510"
    $endif

    $if _device = _18F4515
    $define __DEVICE_ID 99
    $define __DEVICE_NAME "PIC18F4515"
    $endif

    $if _device = _18F4520
    $define __DEVICE_ID 132
    $define __DEVICE_NAME "PIC18F4520"
    $endif

    $if _device = _18F4523
    $define __DEVICE_ID 132
    $define __DEVICE_NAME "PIC18F4523"
    $endif

    $if _device = _18F4525
    $define __DEVICE_ID 98
    $define __DEVICE_NAME "PIC18F4525"
    $endif

    $if _device = _18F4553
    $define __DEVICE_ID 336
    $define __DEVICE_NAME "PIC18F4553"
    $endif

    $if _device = _18F4580
    $define __DEVICE_ID 212
    $define __DEVICE_NAME "PIC18F4580"
    $endif

    $if _device = _18F4585
    $define __DEVICE_ID 117
    $define __DEVICE_NAME "PIC18F4585"
    $endif
'-------------------------------------------------------------------------------
    $if _device = _18F4620
    $define __DEVICE_ID 96    
    $define __DEVICE_NAME "PIC18F4620"
    $endif

    $if _device = _18F4680
    $define __DEVICE_ID 116
    $define __DEVICE_NAME "PIC18F4680"
    $endif

    $if _device = _18F4682
    $define __DEVICE_ID 314
    $define __DEVICE_NAME "PIC18F4682"
    $endif    

    $if _device = _18F4685
    $define __DEVICE_ID 315        
    $define __DEVICE_NAME "PIC18F4685"
    $endif
'-------------------------------------------------------------------------------
    $if _device = _18F13K20
    $define __DEVICE_ID 634
    $define __DEVICE_NAME "PIC18F13K20"
    $endif

    $if _device = _18F14K20
    $define __DEVICE_ID 633
    $define __DEVICE_NAME "PIC18F14K20"
    $endif

    $if _device = _18F23K20
    $define __DEVICE_ID 263
    $define __DEVICE_NAME "PIC18F23K20"
    $endif

    $if _device = _18F24K20
    $define __DEVICE_ID 261
    $define __DEVICE_NAME "PIC18F24K20"
    $endif

    $if _device = _18F25K20
    $define __DEVICE_ID 259
    $define __DEVICE_NAME "PIC18F25K20"
    $endif

    $if _device = _18F26K20
    $define __DEVICE_ID 257
    $define __DEVICE_NAME "PIC18F26K20"
    $endif

    $if _device = _18F43K20
    $define __DEVICE_ID 262
    $define __DEVICE_NAME "PIC18F43K20"
    $endif

    $if _device = _18F44K20
    $define __DEVICE_ID 260
    $define __DEVICE_NAME "PIC18F44K20"
    $endif

    $if _device = _18F45K20
    $define __DEVICE_ID 258
    $define __DEVICE_NAME "PIC18F45K20"
    $endif

    $if _device = _18F46K20
    $define __DEVICE_ID 256
    $define __DEVICE_NAME "PIC18F46K20"
    $endif
'-------------------------------------------------------------------------------
    $if _device = _18F13K22
    $define __DEVICE_ID 633
    $define __DEVICE_NAME "PIC18F13K22"
    $endif

    $if _device = _18F14K22
    $define __DEVICE_ID 634
    $define __DEVICE_NAME "PIC18F14K22"
    $endif

    $if _device = _18F23K22
    $define __DEVICE_ID 698
    $define __DEVICE_NAME "PIC18F23K22"
    $endif

    $if _device = _18F24K22
    $define __DEVICE_ID 690
    $define __DEVICE_NAME "PIC18F24K22"
    $endif

    $if _device = _18F25K22
    $define __DEVICE_ID 682
    $define __DEVICE_NAME "PIC18F25K22"
    $endif

    $if _device = _18F26K22
    $define __DEVICE_ID 674
    $define __DEVICE_NAME "PIC18F26K22"
    $endif

    $if _device = _18F43K22
    $define __DEVICE_ID 696
    $define __DEVICE_NAME "PIC18F43K22"
    $endif

    $if _device = _18F44K22
    $define __DEVICE_ID 688
    $define __DEVICE_NAME "PIC18F44K22"
    $endif

    $if _device = _18F45K22
    $define __DEVICE_ID 680
    $define __DEVICE_NAME "PIC18F45K22"
    $endif

    $if _device = _18F46K22
    $define __DEVICE_ID 672
    $define __DEVICE_NAME "PIC18F46K22"
    $endif

    $if _device = _18F65K22
    $define __DEVICE_ID 664
    $define __DEVICE_NAME "PIC18F65K22"
    $endif

    $if _device = _18F66K22
    $define __DEVICE_ID 662
    $define __DEVICE_NAME "PIC18F66K22"
    $endif

    $if _device = _18F67K22
    $define __DEVICE_ID 652
    $define __DEVICE_NAME "PIC18F67K22"
    $endif    

    $if _device = _18F85K22
    $define __DEVICE_ID 667
    $define __DEVICE_NAME "PIC18F85K22"
    $endif

    $if _device = _18F86K22
    $define __DEVICE_ID 665
    $define __DEVICE_NAME "PIC18F86K22"
    $endif

    $if _device = _18F87K22
    $define __DEVICE_ID 654
    $define __DEVICE_NAME "PIC18F87K22"
    $endif    
'-------------------------------------------------------------------------------
    $if _device = _18F24K40
    $define __DEVICE_ID 27072
    $define __DEVICE_NAME "PIC18F24K40"
    $endif

    $if _device = _18F25K40
    $define __DEVICE_ID 27040
    $define __DEVICE_NAME "PIC18F25K40"
    $endif    
    
    $if _device = _18F26K40
    $define __DEVICE_ID 27008
    $define __DEVICE_NAME "PIC18F26K40"
    $endif
    
    $if _device = _18F27K40
    $define __DEVICE_ID 26976
    $define __DEVICE_NAME "PIC18F27K40"
    $endif

    $if _device = _18F45K40
    $define __DEVICE_ID 26944
    $define __DEVICE_NAME "PIC18F45K40"
    $endif

    $if _device = _18F46K40
    $define __DEVICE_ID 26912
    $define __DEVICE_NAME "PIC18F46K40"
    $endif
    
    $if _device = _18F47K40
    $define __DEVICE_ID 26880
    $define __DEVICE_NAME "PIC18F47K40"
    $endif

    $if _device = _18F65K40
    $define __DEVICE_ID 27392
    $define __DEVICE_NAME "PIC18F65K40"
    $endif

    $if _device = _18F66K40
    $define __DEVICE_ID 27360
    $define __DEVICE_NAME "PIC18F66K40"
    $endif

    $if _device = _18F67K40
    $define __DEVICE_ID 27328
    $define __DEVICE_NAME "PIC18F67K40"
    $endif
'-------------------------------------------------------------------------------
    $if _device = _18F13K50
    $define __DEVICE_ID 570
    $define __DEVICE_NAME "PIC18F13K50"
    $endif

    $if _device = _18F14K50
    $define __DEVICE_ID 571
    $define __DEVICE_NAME "PIC18F14K50"
    $endif

    $if _device = _18F24K50
    $define __DEVICE_ID 743
    $define __DEVICE_NAME "PIC18F24K50"
    $endif

    $if _device = _18F25K50
    $define __DEVICE_ID 737
    $define __DEVICE_NAME "PIC18F25K50"
    $endif    

    $if _device = _18F45K50
    $define __DEVICE_ID 736   
    $define __DEVICE_NAME "PIC18F45K50"
    $endif
'-------------------------------------------------------------------------------
    $if _device = _18F25K80
    $define __DEVICE_ID 780
    $define __DEVICE_NAME "PIC18F25K80"
    $endif

    $if _device = _18F26K80
    $define __DEVICE_ID 777
    $define __DEVICE_NAME "PIC18F26K80"
    $endif

    $if _device = _18F45K80
    $define __DEVICE_ID 779 
    $define __DEVICE_NAME "PIC18F45K80"
    $endif

    $if _device = _18F46K80
    $define __DEVICE_ID 776
    $define __DEVICE_NAME "PIC18F46K80"
    $endif

    $if _device = _18F65K80
    $define __DEVICE_ID 778
    $define __DEVICE_NAME "PIC18F65K80"
    $endif       

    $if _device = _18F66K80
    $define __DEVICE_ID 775
    $define __DEVICE_NAME "PIC18F66K80"
    $endif    
'-------------------------------------------------------------------------------
    $if _device = _18F24J10
    $define __DEVICE_ID 232
    $define __DEVICE_NAME "PIC18F24J10"
    $endif

    $if _device = _18F24J11
    $define __DEVICE_ID 620
    $define __DEVICE_NAME "PIC18F24J11"
    $endif

    $if _device = _18F24J50
    $define __DEVICE_ID 608
    $define __DEVICE_NAME "PIC18F24J50"
    $endif

    $if _device = _18F25J10
    $define __DEVICE_ID 96
    $define __DEVICE_NAME "PIC18F25J10"
    $endif

    $if _device = _18F25J11
    $define __DEVICE_ID 621
    $define __DEVICE_NAME "PIC18F25J11"
    $endif

    $if _device = _18F25J50
    $define __DEVICE_ID 609
    $define __DEVICE_NAME "PIC18F25J50"
    $endif

    $if _device = _18F26J13
    $define __DEVICE_ID 713
    $define __DEVICE_NAME "PIC18F26J13"
    $endif

    $if _device = _18F26J50
    $define __DEVICE_ID 610
    $define __DEVICE_NAME "PIC18F26J50"
    $endif

    $if _device = _18F26J53
    $define __DEVICE_ID 705
    $define __DEVICE_NAME "PIC18F26J53"
    $endif

    $if _device = _18F27J13
    $define __DEVICE_ID = 715
    $define __DEVICE_NAME "PIC18F27J13"
    $endif

    $if _device = _18F27J53
    $define __DEVICE_ID 707
    $define __DEVICE_NAME "PIC18F27J53"
    $endif

    $if _device = _18F44J10
    $define __DEVICE_ID 233
    $define __DEVICE_NAME "PIC18F44J10"
    $endif

    $if _device = _18F44J11
    $define __DEVICE_ID 623
    $define __DEVICE_NAME "PIC18F44J11"
    $endif

    $if _device = _18F45J10
    $define __DEVICE_ID 225
    $define __DEVICE_NAME "PIC18F87K22"
    $endif

    $if _device = _18F45J11
    $define __DEVICE_ID 624
    $define __DEVICE_NAME "PIC18F45J11"
    $endif

    $if _device = _18F45J50
    $define __DEVICE_ID 612
    $define __DEVICE_NAME "PIC18F45J50"
    $endif

    $if _device = _18F46J11
    $define __DEVICE_ID 625
    $define __DEVICE_NAME "PIC18F46J11"
    $endif

    $if _device = _18F46J13
    $define __DEVICE_ID 717
    $define __DEVICE_NAME "PIC18F46J13"
    $endif

    $if _device = _18F46J50
    $define __DEVICE_ID 613
    $define __DEVICE_NAME "PIC18F46J50"
    $endif              
'-------------------------------------------------------------------------------


